@@ -1,5 +1,5 @@
 /*
- *  $Id: rdmsr.c,v 1.10 2001/12/09 16:35:51 davej Exp $
+ *  $Id: rdmsr.c,v 1.16 2003/06/09 22:15:20 davej Exp $
  *  This file is part of x86info.
  *  (C) 2001 Dave Jones.
  *
@@ -16,22 +16,28 @@
 #include <unistd.h>
 #include "x86info.h"
 
-int read_msr(int cpu, unsigned int index, unsigned long long *val)
+int read_msr(int cpu, unsigned int idx, unsigned long long *val)
 {
 	char cpuname[16];
 	unsigned char buffer[8];
 	unsigned long lo, hi;
 	int fh;
+	static int nodriver=0;
+
+	if (nodriver==1)
+		return 0;
 
 	sprintf (cpuname, "/dev/cpu/%d/msr", cpu);
 
 	fh = open (cpuname, O_RDONLY);
 	if (fh==-1) {
-		if (!silent) perror(cpuname);
+		if (!silent)
+			perror(cpuname);
+		nodriver=1;
 		return (0);
 	}
 
-	lseek (fh, index, SEEK_CUR);
+	lseek (fh, idx, SEEK_CUR);
 
 	if (fh != -1) {
 
@@ -55,11 +61,14 @@ void dumpmsr (int cpu, unsigned int msr, int size)
 	unsigned long long val=0;
 
 	if (read_msr(cpu, msr, &val) == 1) {
-		printf ("MSR: 0x%08x=0x%8llx : ", msr, val);
-		if (size==32)
+		if (size==32){
+			printf ("MSR: 0x%08x=0x%08lx : ", msr, (unsigned long) val);
 			binary32(val);
-		if (size==64)
+		}
+		if (size==64) {
+			printf ("MSR: 0x%08x=0x%016llx : ", msr, val);
 			binary64(val);
+		}
 		return;
 	}
 	printf ("Couldn't read MSR 0x%x\n", msr);
